Function get_fast_and_large_temp_dir_base

pub fn get_fast_and_large_temp_dir_base() -> Result<(PathBuf, bool)>
Try to find the best place for putting the evobench.log, while avoiding tmp file cleaners like systemd and staying portable. Also returns if the path is pointing to a tmpfs.